@@ -19,10 +19,11 @@ package org.apache.maven.plugin.dependency;
  * under the License.
  */
 
+import org.apache.maven.plugin.MojoFailureException;
+
 import java.io.File;
 import java.io.IOException;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.Set;
 
 import org.apache.maven.artifact.Artifact;
@@ -103,10 +104,9 @@ public class TestCopyDependenciesMojo
         throws Exception
     {
         mojo.execute();
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertTrue( file.exists() );
@@ -122,26 +122,39 @@ public class TestCopyDependenciesMojo
         mojo.stripVersion = true;
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, true );
             File file = new File( mojo.outputDirectory, fileName );
             assertTrue( file.exists() );
         }
     }
 
+    public void testUseBaseVersion()
+        throws Exception
+    {
+        mojo.useBaseVersion = true;
+        mojo.execute();
+
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
+        {
+            String fileName = DependencyUtil.getFormattedFileName( artifact, false, false, true );
+            File file = new File( mojo.outputDirectory, fileName );
+            assertTrue( file.exists() );
+        }
+    }
+
     public void testNoTransitive()
         throws Exception
     {
         mojo.excludeTransitive = true;
         mojo.execute();
-        Iterator<Artifact> iter = mojo.project.getDependencyArtifacts().iterator();
 
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getDependencyArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertTrue( file.exists() );
@@ -156,10 +169,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeTypes = "jar";
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getType().equalsIgnoreCase( "jar" ), !file.exists() );
@@ -178,10 +190,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertFalse( file.exists() );
@@ -190,10 +201,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeTypes = "";
         mojo.execute();
 
-        iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getType().equalsIgnoreCase( "jar" ), file.exists() );
@@ -209,10 +219,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeArtifactIds = "one";
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getArtifactId().equals( "one" ), !file.exists() );
@@ -231,10 +240,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertFalse( file.exists() );
@@ -243,10 +251,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeArtifactIds = "";
         mojo.execute();
 
-        iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getArtifactId().equals( "one" ), file.exists() );
@@ -264,10 +271,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertFalse( file.exists() );
@@ -276,10 +282,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeGroupIds = "";
         mojo.execute();
 
-        iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getGroupId().equals( "one" ), file.exists() );
@@ -295,10 +300,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeGroupIds = "one";
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
 
@@ -313,10 +317,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeGroupIds = "one,two";
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
 
@@ -332,10 +335,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeClassifiers = "one";
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getClassifier().equals( "one" ), !file.exists() );
@@ -354,10 +356,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertFalse( file.exists() );
@@ -366,10 +367,9 @@ public class TestCopyDependenciesMojo
         mojo.excludeClassifiers = "";
         mojo.execute();
 
-        iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getClassifier().equals( "one" ), file.exists() );
@@ -385,10 +385,9 @@ public class TestCopyDependenciesMojo
         mojo.useSubDirectoryPerType = true;
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File folder = DependencyUtil.getFormattedOutputDirectory( false, true, false, false, false, mojo.outputDirectory,
                                                                       artifact );
@@ -428,11 +427,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
-
             String useClassifier = artifact.getClassifier();
             String useType = artifact.getType();
 
@@ -501,7 +498,7 @@ public class TestCopyDependenciesMojo
      */
 
     public void testDontOverWriteRelease()
-        throws MojoExecutionException, InterruptedException, IOException
+        throws MojoExecutionException, InterruptedException, IOException, MojoFailureException
     {
 
         Set<Artifact> artifacts = new HashSet<Artifact>();
@@ -532,7 +529,7 @@ public class TestCopyDependenciesMojo
     }
 
     public void testOverWriteRelease()
-        throws MojoExecutionException, InterruptedException, IOException
+        throws MojoExecutionException, InterruptedException, IOException, MojoFailureException
     {
 
         Set<Artifact> artifacts = new HashSet<Artifact>();
@@ -566,7 +563,7 @@ public class TestCopyDependenciesMojo
     }
 
     public void testDontOverWriteSnap()
-        throws MojoExecutionException, InterruptedException, IOException
+        throws MojoExecutionException, InterruptedException, IOException, MojoFailureException
     {
 
         Set<Artifact> artifacts = new HashSet<Artifact>();
@@ -599,7 +596,7 @@ public class TestCopyDependenciesMojo
     }
 
     public void testOverWriteSnap()
-        throws MojoExecutionException, InterruptedException, IOException
+        throws MojoExecutionException, InterruptedException, IOException, MojoFailureException
     {
 
         Set<Artifact> artifacts = new HashSet<Artifact>();
@@ -650,10 +647,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getScope().equals( "provided" ), !file.exists() );
@@ -673,10 +669,9 @@ public class TestCopyDependenciesMojo
 
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
             assertEquals( artifact.getScope().equals( "system" ), !file.exists() );
@@ -695,10 +690,9 @@ public class TestCopyDependenciesMojo
         mojo.execute();
         ScopeArtifactFilter saf = new ScopeArtifactFilter( mojo.excludeScope );
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
 
@@ -707,7 +701,7 @@ public class TestCopyDependenciesMojo
     }
 
     public void testExcludeTestScope()
-        throws IOException
+        throws IOException, MojoFailureException
     {
         mojo.project.setArtifacts( stubFactory.getScopedArtifacts() );
         mojo.project.setDependencyArtifacts( new HashSet<Artifact>() );
@@ -734,10 +728,9 @@ public class TestCopyDependenciesMojo
         mojo.execute();
         ScopeArtifactFilter saf = new ScopeArtifactFilter( mojo.excludeScope );
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName );
 
@@ -757,10 +750,9 @@ public class TestCopyDependenciesMojo
         mojo.project.setArtifacts( set );
         mojo.execute();
 
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false );
             File file = new File( mojo.outputDirectory, fileName.substring( 0, fileName.length() - 4 ) + ".pom" );
             assertTrue( file.exists() );
@@ -773,10 +765,9 @@ public class TestCopyDependenciesMojo
         mojo.prependGroupId = true;
         mojo.execute();
     
-        Iterator<Artifact> iter = mojo.project.getArtifacts().iterator();
-        while ( iter.hasNext() )
+        Set<Artifact> artifacts = mojo.project.getArtifacts();
+        for ( Artifact artifact : artifacts )
         {
-            Artifact artifact = iter.next();
             String fileName = DependencyUtil.getFormattedFileName( artifact, false, true );
             File file = new File( mojo.outputDirectory, fileName );
             assertTrue( file.exists() );
