@@ -20,7 +20,6 @@ package org.apache.maven.plugin.dependency.fromConfiguration;
  */
 
 import java.io.File;
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
@@ -68,10 +67,10 @@ public class TestCopyMojo
 
     }
 
-    public ArtifactItem getSingleArtifactItem( boolean removeVersion )
+    public ArtifactItem getSingleArtifactItem( boolean removeVersion, boolean useBaseVersion )
         throws MojoExecutionException
     {
-        List<ArtifactItem> list = mojo.getProcessedArtifactItems( removeVersion );
+        List<ArtifactItem> list = mojo.getProcessedArtifactItems(new ProcessArtifactItemsRequest( removeVersion, false, useBaseVersion ));
         return list.get( 0 );
     }
 
@@ -90,12 +89,12 @@ public class TestCopyMojo
 
         mojo.setArtifactItems( list );
 
-        ArtifactItem result = getSingleArtifactItem( false );
+        ArtifactItem result = getSingleArtifactItem( false, false );
         assertEquals( mojo.getOutputDirectory(), result.getOutputDirectory() );
 
         File output = new File( mojo.getOutputDirectory(), "override" );
         item.setOutputDirectory( output );
-        result = getSingleArtifactItem( false );
+        result = getSingleArtifactItem( false, false );
         assertEquals( output, result.getOutputDirectory() );
     }
 
@@ -122,7 +121,7 @@ public class TestCopyMojo
     }
 
     public void testCopyFile()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
 
@@ -133,8 +132,28 @@ public class TestCopyMojo
         assertFilesExist( list, true );
     }
     
+    public void testCopyFileWithBaseVersion()
+        throws Exception
+    {
+        List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
+        ArtifactItem item = new ArtifactItem();
+
+        item.setArtifactId( "artifact" );
+        item.setGroupId( "groupId" );
+        item.setVersion( "1.0-20130210.213424-191" );
+        item.setBaseVersion( "1.0-SNAPSHOT" );
+        list.add(item);
+
+        mojo.setArtifactItems( list );
+        mojo.setUseBaseVersion(true);
+
+        mojo.execute();
+
+        assertFilesExist( list, true );
+    }
+    
     public void testSkip()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
 
@@ -152,7 +171,7 @@ public class TestCopyMojo
     }
 
     public void testCopyFileNoOverwrite()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
 
@@ -169,7 +188,7 @@ public class TestCopyMojo
     }
 
     public void testCopyToLocation()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
         ArtifactItem item = (ArtifactItem) list.get( 0 );
@@ -183,7 +202,7 @@ public class TestCopyMojo
     }
 
     public void testCopyStripVersionSetInMojo()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
         ArtifactItem item = (ArtifactItem) list.get( 0 );
@@ -199,7 +218,7 @@ public class TestCopyMojo
     }
 
     public void testNonClassifierStrip()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getReleaseAndSnapshotArtifacts() );
         mojo.setStripVersion( true );
@@ -211,7 +230,7 @@ public class TestCopyMojo
     }
 
     public void testNonClassifierNoStrip()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getReleaseAndSnapshotArtifacts() );
 
@@ -223,7 +242,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionNotFound()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -271,7 +290,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionFromDependencies()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -293,7 +312,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionFromDependenciesLooseMatch()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -318,7 +337,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionFromDependenciesWithClassifier()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -363,7 +382,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionFromDependencyMgt()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -396,7 +415,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionFromDependencyMgtLooseMatch()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -430,7 +449,7 @@ public class TestCopyMojo
     }
 
     public void testMissingVersionFromDependencyMgtWithClassifier()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -516,7 +535,7 @@ public class TestCopyMojo
     {
         try
         {
-            mojo.getProcessedArtifactItems( false );
+            mojo.getProcessedArtifactItems( new ProcessArtifactItemsRequest( false, false, false ) );
             fail( "Expected Exception" );
         }
         catch ( MojoExecutionException e )
@@ -527,7 +546,7 @@ public class TestCopyMojo
     }
 
     public void testCopyDontOverWriteReleases()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact release = stubFactory.getReleaseArtifact();
@@ -558,7 +577,7 @@ public class TestCopyMojo
     }
 
     public void testCopyDontOverWriteSnapshots()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact artifact = stubFactory.getSnapshotArtifact();
@@ -589,7 +608,7 @@ public class TestCopyMojo
     }
 
     public void testCopyOverWriteReleases()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact release = stubFactory.getReleaseArtifact();
@@ -617,7 +636,7 @@ public class TestCopyMojo
     }
 
     public void testCopyOverWriteSnapshot()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact artifact = stubFactory.getSnapshotArtifact();
@@ -646,7 +665,7 @@ public class TestCopyMojo
     }
 
     public void testCopyOverWriteIfNewer()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact artifact = stubFactory.getSnapshotArtifact();
@@ -675,7 +694,7 @@ public class TestCopyMojo
     }
     
     public void testCopyFileWithOverideLocalRepo()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
 
