@@ -76,6 +76,7 @@ public class TestUnpackMojo
         mojo.setResolver( new StubArtifactResolver( stubFactory, false, false ) );
         mojo.setLocal( new StubArtifactRepository( this.testDir.getAbsolutePath() ) );
         mojo.setArtifactCollector( new StubArtifactCollector() );
+        mojo.setUseJvmChmod( true );
     }
 
     public ArtifactItem getSingleArtifactItem( boolean removeVersion )
@@ -131,7 +132,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackFile()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
 
@@ -143,7 +144,7 @@ public class TestUnpackMojo
     }
     
     public void testSkip()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
 
@@ -156,7 +157,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackToLocation()
-        throws IOException, MojoExecutionException
+        throws Exception
     {
         List<ArtifactItem> list = stubFactory.getArtifactItems( stubFactory.getClassifiedArtifacts() );
         ArtifactItem item = (ArtifactItem) list.get( 0 );
@@ -170,7 +171,7 @@ public class TestUnpackMojo
     }
 
     public void testMissingVersionNotFound()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -218,7 +219,7 @@ public class TestUnpackMojo
     }
 
     public void testMissingVersionFromDependencies()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -240,7 +241,7 @@ public class TestUnpackMojo
     }
 
     public void testMissingVersionFromDependenciesWithClassifier()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -285,7 +286,7 @@ public class TestUnpackMojo
     }
 
     public void testMissingVersionFromDependencyMgt()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -317,7 +318,7 @@ public class TestUnpackMojo
     }
 
     public void testMissingVersionFromDependencyMgtWithClassifier()
-        throws MojoExecutionException
+        throws Exception
     {
         ArtifactItem item = new ArtifactItem();
 
@@ -414,7 +415,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackDontOverWriteReleases()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact release = stubFactory.getReleaseArtifact();
@@ -434,7 +435,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackDontOverWriteSnapshots()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact artifact = stubFactory.getSnapshotArtifact();
@@ -454,7 +455,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackOverWriteReleases()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact release = stubFactory.getReleaseArtifact();
@@ -474,7 +475,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackOverWriteSnapshot()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         stubFactory.setCreateFiles( true );
         Artifact artifact = stubFactory.getSnapshotArtifact();
@@ -495,7 +496,7 @@ public class TestUnpackMojo
     }
 
     public void testUnpackOverWriteIfNewer()
-        throws IOException, MojoExecutionException, InterruptedException
+        throws Exception
     {
         final long now = System.currentTimeMillis();
         
@@ -547,7 +548,7 @@ public class TestUnpackMojo
     }
     
     public void assertUnpacked( ArtifactItem item, boolean overWrite )
-        throws InterruptedException, MojoExecutionException
+        throws Exception
     {
 
         File unpackedFile = getUnpackedFile( item );
